# do not import all endpoints into this module because that uses a lot of memory and stack frames
# if you need the ability to import all endpoints from this module, import them with
# from openapi_sol_api.paths.account_network_address_nft import Api

from openapi_sol_api.paths import PathValues

path = PathValues.ACCOUNT_NETWORK_ADDRESS_NFT