# coding: utf-8

"""
    Streams Api

    API that provides access to Moralis Streams  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from openapi_streams import schemas  # noqa: F401


class PartialStreamsTypesStreamsModelCreate(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.

    Make all properties in T optional
    """


    class MetaOapg:
        
        class properties:
            webhookUrl = schemas.StrSchema
            description = schemas.StrSchema
            tag = schemas.StrSchema
            
            
            class topic0(
                schemas.ListBase,
                schemas.NoneBase,
                schemas.Schema,
                schemas.NoneTupleMixin
            ):
            
            
                class MetaOapg:
                    items = schemas.StrSchema
            
            
                def __new__(
                    cls,
                    *_args: typing.Union[list, tuple, None, ],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'topic0':
                    return super().__new__(
                        cls,
                        *_args,
                        _configuration=_configuration,
                    )
            allAddresses = schemas.BoolSchema
            includeNativeTxs = schemas.BoolSchema
            includeContractLogs = schemas.BoolSchema
            includeInternalTxs = schemas.BoolSchema
            
            
            class abi(
                schemas.ListBase,
                schemas.NoneBase,
                schemas.Schema,
                schemas.NoneTupleMixin
            ):
            
            
                class MetaOapg:
                    
                    @staticmethod
                    def items() -> typing.Type['AbiItem']:
                        return AbiItem
            
            
                def __new__(
                    cls,
                    *_args: typing.Union[list, tuple, None, ],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'abi':
                    return super().__new__(
                        cls,
                        *_args,
                        _configuration=_configuration,
                    )
            
            
            class advancedOptions(
                schemas.ListBase,
                schemas.NoneBase,
                schemas.Schema,
                schemas.NoneTupleMixin
            ):
            
            
                class MetaOapg:
                    
                    @staticmethod
                    def items() -> typing.Type['AdvancedOptions']:
                        return AdvancedOptions
            
            
                def __new__(
                    cls,
                    *_args: typing.Union[list, tuple, None, ],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'advancedOptions':
                    return super().__new__(
                        cls,
                        *_args,
                        _configuration=_configuration,
                    )
            
            
            class chainIds(
                schemas.ListSchema
            ):
            
            
                class MetaOapg:
                    items = schemas.StrSchema
            
                def __new__(
                    cls,
                    _arg: typing.Union[typing.Tuple[typing.Union[MetaOapg.items, str, ]], typing.List[typing.Union[MetaOapg.items, str, ]]],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'chainIds':
                    return super().__new__(
                        cls,
                        _arg,
                        _configuration=_configuration,
                    )
            
                def __getitem__(self, i: int) -> MetaOapg.items:
                    return super().__getitem__(i)
            __annotations__ = {
                "webhookUrl": webhookUrl,
                "description": description,
                "tag": tag,
                "topic0": topic0,
                "allAddresses": allAddresses,
                "includeNativeTxs": includeNativeTxs,
                "includeContractLogs": includeContractLogs,
                "includeInternalTxs": includeInternalTxs,
                "abi": abi,
                "advancedOptions": advancedOptions,
                "chainIds": chainIds,
            }
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["webhookUrl"]) -> MetaOapg.properties.webhookUrl: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["description"]) -> MetaOapg.properties.description: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["tag"]) -> MetaOapg.properties.tag: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["topic0"]) -> MetaOapg.properties.topic0: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["allAddresses"]) -> MetaOapg.properties.allAddresses: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["includeNativeTxs"]) -> MetaOapg.properties.includeNativeTxs: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["includeContractLogs"]) -> MetaOapg.properties.includeContractLogs: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["includeInternalTxs"]) -> MetaOapg.properties.includeInternalTxs: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["abi"]) -> MetaOapg.properties.abi: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["advancedOptions"]) -> MetaOapg.properties.advancedOptions: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["chainIds"]) -> MetaOapg.properties.chainIds: ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["webhookUrl", "description", "tag", "topic0", "allAddresses", "includeNativeTxs", "includeContractLogs", "includeInternalTxs", "abi", "advancedOptions", "chainIds", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["webhookUrl"]) -> typing.Union[MetaOapg.properties.webhookUrl, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["description"]) -> typing.Union[MetaOapg.properties.description, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["tag"]) -> typing.Union[MetaOapg.properties.tag, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["topic0"]) -> typing.Union[MetaOapg.properties.topic0, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["allAddresses"]) -> typing.Union[MetaOapg.properties.allAddresses, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["includeNativeTxs"]) -> typing.Union[MetaOapg.properties.includeNativeTxs, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["includeContractLogs"]) -> typing.Union[MetaOapg.properties.includeContractLogs, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["includeInternalTxs"]) -> typing.Union[MetaOapg.properties.includeInternalTxs, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["abi"]) -> typing.Union[MetaOapg.properties.abi, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["advancedOptions"]) -> typing.Union[MetaOapg.properties.advancedOptions, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["chainIds"]) -> typing.Union[MetaOapg.properties.chainIds, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["webhookUrl", "description", "tag", "topic0", "allAddresses", "includeNativeTxs", "includeContractLogs", "includeInternalTxs", "abi", "advancedOptions", "chainIds", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *_args: typing.Union[dict, frozendict.frozendict, ],
        webhookUrl: typing.Union[MetaOapg.properties.webhookUrl, str, schemas.Unset] = schemas.unset,
        description: typing.Union[MetaOapg.properties.description, str, schemas.Unset] = schemas.unset,
        tag: typing.Union[MetaOapg.properties.tag, str, schemas.Unset] = schemas.unset,
        topic0: typing.Union[MetaOapg.properties.topic0, list, tuple, None, schemas.Unset] = schemas.unset,
        allAddresses: typing.Union[MetaOapg.properties.allAddresses, bool, schemas.Unset] = schemas.unset,
        includeNativeTxs: typing.Union[MetaOapg.properties.includeNativeTxs, bool, schemas.Unset] = schemas.unset,
        includeContractLogs: typing.Union[MetaOapg.properties.includeContractLogs, bool, schemas.Unset] = schemas.unset,
        includeInternalTxs: typing.Union[MetaOapg.properties.includeInternalTxs, bool, schemas.Unset] = schemas.unset,
        abi: typing.Union[MetaOapg.properties.abi, list, tuple, None, schemas.Unset] = schemas.unset,
        advancedOptions: typing.Union[MetaOapg.properties.advancedOptions, list, tuple, None, schemas.Unset] = schemas.unset,
        chainIds: typing.Union[MetaOapg.properties.chainIds, list, tuple, schemas.Unset] = schemas.unset,
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'PartialStreamsTypesStreamsModelCreate':
        return super().__new__(
            cls,
            *_args,
            webhookUrl=webhookUrl,
            description=description,
            tag=tag,
            topic0=topic0,
            allAddresses=allAddresses,
            includeNativeTxs=includeNativeTxs,
            includeContractLogs=includeContractLogs,
            includeInternalTxs=includeInternalTxs,
            abi=abi,
            advancedOptions=advancedOptions,
            chainIds=chainIds,
            _configuration=_configuration,
            **kwargs,
        )

from openapi_streams.model.abi_item import AbiItem
from openapi_streams.model.advanced_options import AdvancedOptions
